@@ -1,4 +1,4 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import Schema, fields, post_load, EXCLUDE
 from ..resource import Resource
 
 
@@ -18,4 +18,4 @@ class Attributes(Resource):
         def make(self, data, **kwargs):
             return Attributes(**data)
 
-    _schema = _Schema()
+    _schema = _Schema(unknown=EXCLUDE)
