@@ -1,4 +1,4 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import Schema, fields, post_load, EXCLUDE
 from ..resource import Resource
 from collections import namedtuple
 
@@ -22,4 +22,4 @@ class DataSource(Resource):
         def make(self, data, **kwargs):
             return DataSource(**data)
 
-    _schema = _Schema()
+    _schema = _Schema(unknown=EXCLUDE)
