@@ -1,4 +1,4 @@
-from marshmallow import Schema, fields, post_load
+from marshmallow import Schema, fields, post_load, EXCLUDE
 from ..resource import Resource
 
 
@@ -20,4 +20,4 @@ class Transaction(Resource):
         def make(self, data, **kwargs):
             return Transaction(**data)
 
-    _schema = _Schema()
+    _schema = _Schema(unknown=EXCLUDE)
