@@ -14,32 +14,35 @@ from .version import __version__
 HTTP verb mapping. Based on nodejs library.
 """
 MAPPINGS = {
-    'add': 'post',
-    'all': 'get',
-    'cancel': 'patch',
-    'create': 'post',
-    'destroy': 'delete',
-    'merge': 'patch',
-    'modify': 'patch',
-    'patch': 'patch',
-    'remove': 'delete',
-    'retrieve': 'get',
-    'update': 'put',
-    'destroy_with_params': 'delete',
-    'modify_with_params': 'patch'
+    "add": "post",
+    "all": "get",
+    "cancel": "patch",
+    "create": "post",
+    "destroy": "delete",
+    "merge": "patch",
+    "modify": "patch",
+    "patch": "patch",
+    "remove": "delete",
+    "retrieve": "get",
+    "update": "put",
+    "destroy_with_params": "delete",
+    "modify_with_params": "patch",
 }
 
-LIST_PARAMS = ['current_page', 'total_pages',
-               'has_more', 'per_page', 'page',
-               'summary', 'customer_uuid', 'meta']
-ESCAPED_QUERY_KEYS = {
-    'start_date': 'start-date',
-    'end_date': 'end-date'
-}
+LIST_PARAMS = [
+    "current_page",
+    "total_pages",
+    "has_more",
+    "per_page",
+    "page",
+    "summary",
+    "customer_uuid",
+    "meta",
+]
+ESCAPED_QUERY_KEYS = {"start_date": "start-date", "end_date": "end-date"}
 
 
 class DataObject(object):
-
     def __init__(self, **kwargs):
         """
         Any arguments are translated into class attributes.
@@ -59,10 +62,19 @@ class DataObject(object):
         Pretty-prints any object as
         <ClassName{property='string',number=4,date=datetime.datetime(2003, 8, 4, 21, 41, 43)}>
         """
-        return "<" + self.__class__.__name__ + "{" + \
-            ", ".join([attr + "=" + repr(getattr(self, attr)) for attr in sorted(dir(self))
-                       if not attr.startswith('_') and not callable(getattr(self, attr))]) + \
-               "}>"
+        return (
+            "<"
+            + self.__class__.__name__
+            + "{"
+            + ", ".join(
+                [
+                    attr + "=" + repr(getattr(self, attr))
+                    for attr in sorted(dir(self))
+                    if not attr.startswith("_") and not callable(getattr(self, attr))
+                ]
+            )
+            + "}>"
+        )
 
 
 def json_serial(obj):
@@ -78,7 +90,7 @@ def json_serial(obj):
 
 
 class Resource(DataObject):
-    _path = ''
+    _path = ""
 
     @classmethod
     def _load(cls, response):
@@ -99,9 +111,11 @@ class Resource(DataObject):
     @classmethod
     def _loadJSON(cls, jsonObj):
         # has load_many capability & is many entries result?
-        if '_root_key' in dir(cls) is not None and cls._root_key in jsonObj:
-            return cls._many(cls._schema.load(jsonObj[cls._root_key], many=True), **{
-                             key: jsonObj[key] for key in LIST_PARAMS if key in jsonObj})
+        if "_root_key" in dir(cls) is not None and cls._root_key in jsonObj:
+            return cls._many(
+                cls._schema.load(jsonObj[cls._root_key], many=True),
+                **{key: jsonObj[key] for key in LIST_PARAMS if key in jsonObj}
+            )
         else:
             return cls._schema.load(jsonObj)
 
@@ -115,7 +129,7 @@ class Resource(DataObject):
 
     @classmethod
     def _request(cls, config, method, http_verb, path, data=None, **kwargs):
-        if http_verb == 'get':
+        if http_verb == "get":
             params = cls._preProcessParams(kwargs)
             data = None
         else:
@@ -123,22 +137,30 @@ class Resource(DataObject):
             if data is not None:
                 data = dumps(data, default=json_serial)
 
-        return Promise(
-            lambda resolve,
-            _: resolve(
-                getattr(
-                    requests_retry_session(
-                        config.max_retries,
-                        config.backoff_factor),
-                    http_verb)(
-                    config.uri + path,
-                    data=data,
-                    headers={
-                        'content-type': 'application/json', 'User-Agent': 'chartmogul-python/' + __version__},
-                    params=params,
-                    auth=config.auth,
-                    timeout=config.request_timeout))).then(
-            cls._load).catch(annotateHTTPError)
+        return (
+            Promise(
+                lambda resolve, _: resolve(
+                    getattr(
+                        requests_retry_session(
+                            config.max_retries, config.backoff_factor
+                        ),
+                        http_verb,
+                    )(
+                        config.uri + path,
+                        data=data,
+                        headers={
+                            "content-type": "application/json",
+                            "User-Agent": "chartmogul-python/" + __version__,
+                        },
+                        params=params,
+                        auth=config.auth,
+                        timeout=config.request_timeout,
+                    )
+                )
+            )
+            .then(cls._load)
+            .catch(annotateHTTPError)
+        )
 
     @classmethod
     def _expandPath(cls, path, kwargs):
@@ -149,15 +171,31 @@ class Resource(DataObject):
     def _validate_arguments(cls, method, kwargs):
         # This enforces user to pass argument, otherwise we could call
         # wrong URL.
-        if method in ['destroy', 'cancel', 'retrieve', 'modify', 'update'] and 'uuid' not in kwargs:
+        if (
+            method in ["destroy", "cancel", "retrieve", "modify", "update"]
+            and "uuid" not in kwargs
+        ):
             raise ArgumentMissingError("Please pass 'uuid' parameter")
-        if method in ['create', 'modify'] and 'data' not in kwargs:
+        if method in ["create", "modify"] and "data" not in kwargs:
             raise ArgumentMissingError("Please pass 'data' parameter")
-        if method in ['destroy_all'] and 'data_source_uuid' not in kwargs and 'customer_uuid' not in kwargs:
-            raise ArgumentMissingError("Please pass 'data_source_uuid' and 'customer_uuid' parameters")
-        if method in ['destroy_with_params', 'modify_with_params'] and not('id' in kwargs['data']['subscription_event']
-        or ('external_id' in kwargs['data']['subscription_event'] and 'data_source_uuid' in kwargs['data']['subscription_event'])):
-            raise ArgumentMissingError("Please pass 'id' parameter or 'data_source_uuid' and 'external_id'")
+        if (
+            method in ["destroy_all"]
+            and "data_source_uuid" not in kwargs
+            and "customer_uuid" not in kwargs
+        ):
+            raise ArgumentMissingError(
+                "Please pass 'data_source_uuid' and 'customer_uuid' parameters"
+            )
+        if method in ["destroy_with_params", "modify_with_params"] and not (
+            "id" in kwargs["data"]["subscription_event"]
+            or (
+                "external_id" in kwargs["data"]["subscription_event"]
+                and "data_source_uuid" in kwargs["data"]["subscription_event"]
+            )
+        ):
+            raise ArgumentMissingError(
+                "Please pass 'id' parameter or 'data_source_uuid' and 'external_id'"
+            )
 
     @classmethod
     def _method(cls, method, http_verb, path=None):
@@ -165,8 +203,8 @@ class Resource(DataObject):
         def fc(cls, config, **kwargs):
             if config is None or not isinstance(config, Config):
                 raise ConfigurationError(
-                    "First argument should be"
-                    " instance of chartmogul.Config class!")
+                    "First argument should be" " instance of chartmogul.Config class!"
+                )
 
             pathTemp = path  # due to Python closure
             if pathTemp is None:
@@ -176,10 +214,11 @@ class Resource(DataObject):
 
             pathTemp = Resource._expandPath(pathTemp, kwargs)
             # UUID is always path parameter only.
-            if 'uuid' in kwargs:
-                del kwargs['uuid']
+            if "uuid" in kwargs:
+                del kwargs["uuid"]
 
             return cls._request(config, method, http_verb, pathTemp, **kwargs)
+
         return fc
 
 
